
#ifndef _C11_ki548_
#define _C11_ki548_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F89_980(EIF_REFERENCE);
extern void F89_987(EIF_REFERENCE);
extern void EIF_Minit548(void);

#ifdef __cplusplus
}
#endif

#endif
